
.fontello-icon-file-word:before { content: '\e800'; } /* '' */
.fontello-icon-file-excel:before { content: '\e801'; } /* '' */
.fontello-icon-file-pdf:before { content: '\e802'; } /* '' */
.fontello-icon-doc:before { content: '\e803'; } /* '' */
.fontello-icon-doc-text:before { content: '\e804'; } /* '' */
.fontello-icon-file-audio:before { content: '\e805'; } /* '' */
.fontello-icon-file-video:before { content: '\e806'; } /* '' */
.fontello-icon-popup:before { content: '\e807'; } /* '' */