
/*TODO Need to implement as Less*/

.flex-container {
    display: flex;
}

.flex-container.row {
    flex-direction: row;
}

.flex-container.space-between {
    justify-content: space-between;
}

.flex-container.row.wrap {
    flex-wrap: wrap;
}

.app-assetmanager #content-main li {
    margin-left: 20px;
}

.app-assetmanager #content-main ul {
    list-style-type: none;
    padding: 0;
}

.app-assetmanager .file .icon {
    font-size: 7em;
}

.app-assetmanager .file .name {
    text-align: center;
}

.app-assetmanager .file .icon-popup {
    font-size: 1em;
}

.assetmanager-file {
    float: left;
}

.asset-manager-link img {
    max-width: 200px;
}
